@@ -35,7 +35,7 @@
 #include <bits/os_defines.h>
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20050401
+#define __GLIBCXX__ 20050226
 
 // Allow use of "export template." This is currently not a feature
 // that g++ supports.
@@ -51,6 +51,13 @@
 # define _GLIBCXX_EXTERN_TEMPLATE 1
 #endif
 
+// Certain function definitions that are meant to be overridable from
+// user code are decorated with this macro.  For some targets, this
+// macro causes these definitions to be weak.
+#ifndef _GLIBCXX_WEAK_DEFINITION
+# define _GLIBCXX_WEAK_DEFINITION
+#endif
+
 // Debug mode support. Debug mode basic_string is not allowed to be
 // associated with std, because of locale and exception link
 // dependence.
@@ -110,14 +117,14 @@ namespace std
 // Include I/O support for 'long long' and 'unsigned long long'.
 #define _GLIBCXX_USE_LONG_LONG 1
 
-// Include support for 'long double'.
-/* #undef _GLIBCXX_USE_LONG_DOUBLE */
+// Define if C99 features such as lldiv_t, llabs, lldiv should be exposed.
+/* #undef _GLIBCXX_USE_C99 */
 
 // Define if C99 math functions (like fpclassify) should be exposed.
 /* #undef _GLIBCXX_USE_C99_MATH */
 
-// Define if C99 features such as lldiv_t, llabs, lldiv should be exposed.
-/* #undef _GLIBCXX_USE_C99 */
+// Define if C99 complex math functions should be used in std::complex.
+/* #undef _GLIBCXX_USE_C99_COMPLEX */
 
 // Define if code specialized for wchar_t should be used.
 /* #undef _GLIBCXX_USE_WCHAR_T */
@@ -176,7 +183,7 @@ namespace std
 #define _GLIBCXX_HAVE_SIGSETJMP 1
 
 // Define if mbstate_t exists in wchar.h.
-#define _GLIBCXX_HAVE_MBSTATE_T 1
+/* #undef _GLIBCXX_HAVE_MBSTATE_T */
 
 // Define if you have the modff function.
 #define _GLIBCXX_HAVE_MODFF 1
@@ -291,7 +298,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ATANL */
 
 /* Define to 1 if you have the `btowc' function. */
-#define _GLIBCXX_HAVE_BTOWC 1
+/* #undef _GLIBCXX_HAVE_BTOWC */
 
 /* Define to 1 if you have the `ceilf' function. */
 #define _GLIBCXX_HAVE_CEILF 1
@@ -299,6 +306,9 @@ namespace std
 /* Define to 1 if you have the `ceill' function. */
 /* #undef _GLIBCXX_HAVE_CEILL */
 
+/* Define to 1 if you have the <complex.h> header file. */
+/* #undef _GLIBCXX_HAVE_COMPLEX_H */
+
 /* Define to 1 if you have the `copysign' function. */
 #define _GLIBCXX_HAVE_COPYSIGN 1
 
@@ -336,10 +346,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FABSL */
 
 /* Define to 1 if you have the `fgetwc' function. */
-#define _GLIBCXX_HAVE_FGETWC 1
+/* #undef _GLIBCXX_HAVE_FGETWC */
 
 /* Define to 1 if you have the `fgetws' function. */
-#define _GLIBCXX_HAVE_FGETWS 1
+/* #undef _GLIBCXX_HAVE_FGETWS */
 
 /* Define to 1 if you have the `finite' function. */
 #define _GLIBCXX_HAVE_FINITE 1
@@ -369,10 +379,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FPCLASS */
 
 /* Define to 1 if you have the `fputwc' function. */
-#define _GLIBCXX_HAVE_FPUTWC 1
+/* #undef _GLIBCXX_HAVE_FPUTWC */
 
 /* Define to 1 if you have the `fputws' function. */
-#define _GLIBCXX_HAVE_FPUTWS 1
+/* #undef _GLIBCXX_HAVE_FPUTWS */
 
 /* Define to 1 if you have the <fp.h> header file. */
 /* #undef _GLIBCXX_HAVE_FP_H */
@@ -384,7 +394,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_FREXPL */
 
 /* Define to 1 if you have the `fwide' function. */
-#define _GLIBCXX_HAVE_FWIDE 1
+/* #undef _GLIBCXX_HAVE_FWIDE */
 
 /* Define to 1 if you have the `fwprintf' function. */
 /* #undef _GLIBCXX_HAVE_FWPRINTF */
@@ -399,10 +409,10 @@ namespace std
 #define _GLIBCXX_HAVE_GETPAGESIZE 1
 
 /* Define to 1 if you have the `getwc' function. */
-#define _GLIBCXX_HAVE_GETWC 1
+/* #undef _GLIBCXX_HAVE_GETWC */
 
 /* Define to 1 if you have the `getwchar' function. */
-#define _GLIBCXX_HAVE_GETWCHAR 1
+/* #undef _GLIBCXX_HAVE_GETWCHAR */
 
 /* Define to 1 if you have the `hypot' function. */
 #define _GLIBCXX_HAVE_HYPOT 1
@@ -447,7 +457,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_ISNANL */
 
 /* Define to 1 if you have the `iswblank' function. */
-#define _GLIBCXX_HAVE_ISWBLANK 1
+/* #undef _GLIBCXX_HAVE_ISWBLANK */
 
 /* Define to 1 if you have the `ldexpf' function. */
 #define _GLIBCXX_HAVE_LDEXPF 1
@@ -498,16 +508,16 @@ namespace std
 #define _GLIBCXX_HAVE_MACHINE_PARAM_H 1
 
 /* Define to 1 if you have the `mbrlen' function. */
-#define _GLIBCXX_HAVE_MBRLEN 1
+/* #undef _GLIBCXX_HAVE_MBRLEN */
 
 /* Define to 1 if you have the `mbrtowc' function. */
-#define _GLIBCXX_HAVE_MBRTOWC 1
+/* #undef _GLIBCXX_HAVE_MBRTOWC */
 
 /* Define to 1 if you have the `mbsinit' function. */
-#define _GLIBCXX_HAVE_MBSINIT 1
+/* #undef _GLIBCXX_HAVE_MBSINIT */
 
 /* Define to 1 if you have the `mbsrtowcs' function. */
-#define _GLIBCXX_HAVE_MBSRTOWCS 1
+/* #undef _GLIBCXX_HAVE_MBSRTOWCS */
 
 /* Define to 1 if you have the <memory.h> header file. */
 #define _GLIBCXX_HAVE_MEMORY_H 1
@@ -525,7 +535,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_NAN_H */
 
 /* Define to 1 if you have the `nl_langinfo' function. */
-#define _GLIBCXX_HAVE_NL_LANGINFO 1
+/* #undef _GLIBCXX_HAVE_NL_LANGINFO */
 
 /* Define to 1 if you have the `powf' function. */
 #define _GLIBCXX_HAVE_POWF 1
@@ -534,10 +544,10 @@ namespace std
 /* #undef _GLIBCXX_HAVE_POWL */
 
 /* Define to 1 if you have the `putwc' function. */
-#define _GLIBCXX_HAVE_PUTWC 1
+/* #undef _GLIBCXX_HAVE_PUTWC */
 
 /* Define to 1 if you have the `putwchar' function. */
-#define _GLIBCXX_HAVE_PUTWCHAR 1
+/* #undef _GLIBCXX_HAVE_PUTWCHAR */
 
 /* Define to 1 if you have the `qfpclass' function. */
 /* #undef _GLIBCXX_HAVE_QFPCLASS */
@@ -605,6 +615,9 @@ namespace std
 /* Define to 1 if you have the <sys/ioctl.h> header file. */
 #define _GLIBCXX_HAVE_SYS_IOCTL_H 1
 
+/* Define to 1 if you have the <sys/ipc.h> header file. */
+#define _GLIBCXX_HAVE_SYS_IPC_H 1
+
 /* Define to 1 if you have the <sys/isa_defs.h> header file. */
 /* #undef _GLIBCXX_HAVE_SYS_ISA_DEFS_H */
 
@@ -617,6 +630,9 @@ namespace std
 /* Define to 1 if you have the <sys/resource.h> header file. */
 #define _GLIBCXX_HAVE_SYS_RESOURCE_H 1
 
+/* Define to 1 if you have the <sys/sem.h> header file. */
+#define _GLIBCXX_HAVE_SYS_SEM_H 1
+
 /* Define to 1 if you have the <sys/stat.h> header file. */
 #define _GLIBCXX_HAVE_SYS_STAT_H 1
 
@@ -642,7 +658,7 @@ namespace std
 /* #undef _GLIBCXX_HAVE_TANL */
 
 /* Define to 1 if you have the `ungetwc' function. */
-#define _GLIBCXX_HAVE_UNGETWC 1
+/* #undef _GLIBCXX_HAVE_UNGETWC */
 
 /* Define to 1 if you have the <unistd.h> header file. */
 #define _GLIBCXX_HAVE_UNISTD_H 1
@@ -666,97 +682,97 @@ namespace std
 /* #undef _GLIBCXX_HAVE_VWSCANF */
 
 /* Define to 1 if you have the <wchar.h> header file. */
-#define _GLIBCXX_HAVE_WCHAR_H 1
+/* #undef _GLIBCXX_HAVE_WCHAR_H */
 
 /* Define to 1 if you have the `wcrtomb' function. */
-#define _GLIBCXX_HAVE_WCRTOMB 1
+/* #undef _GLIBCXX_HAVE_WCRTOMB */
 
 /* Define to 1 if you have the `wcscat' function. */
-#define _GLIBCXX_HAVE_WCSCAT 1
+/* #undef _GLIBCXX_HAVE_WCSCAT */
 
 /* Define to 1 if you have the `wcschr' function. */
-#define _GLIBCXX_HAVE_WCSCHR 1
+/* #undef _GLIBCXX_HAVE_WCSCHR */
 
 /* Define to 1 if you have the `wcscmp' function. */
-#define _GLIBCXX_HAVE_WCSCMP 1
+/* #undef _GLIBCXX_HAVE_WCSCMP */
 
 /* Define to 1 if you have the `wcscoll' function. */
-#define _GLIBCXX_HAVE_WCSCOLL 1
+/* #undef _GLIBCXX_HAVE_WCSCOLL */
 
 /* Define to 1 if you have the `wcscpy' function. */
-#define _GLIBCXX_HAVE_WCSCPY 1
+/* #undef _GLIBCXX_HAVE_WCSCPY */
 
 /* Define to 1 if you have the `wcscspn' function. */
-#define _GLIBCXX_HAVE_WCSCSPN 1
+/* #undef _GLIBCXX_HAVE_WCSCSPN */
 
 /* Define to 1 if you have the `wcsftime' function. */
 /* #undef _GLIBCXX_HAVE_WCSFTIME */
 
 /* Define to 1 if you have the `wcslen' function. */
-#define _GLIBCXX_HAVE_WCSLEN 1
+/* #undef _GLIBCXX_HAVE_WCSLEN */
 
 /* Define to 1 if you have the `wcsncat' function. */
-#define _GLIBCXX_HAVE_WCSNCAT 1
+/* #undef _GLIBCXX_HAVE_WCSNCAT */
 
 /* Define to 1 if you have the `wcsncmp' function. */
-#define _GLIBCXX_HAVE_WCSNCMP 1
+/* #undef _GLIBCXX_HAVE_WCSNCMP */
 
 /* Define to 1 if you have the `wcsncpy' function. */
-#define _GLIBCXX_HAVE_WCSNCPY 1
+/* #undef _GLIBCXX_HAVE_WCSNCPY */
 
 /* Define to 1 if you have the `wcspbrk' function. */
-#define _GLIBCXX_HAVE_WCSPBRK 1
+/* #undef _GLIBCXX_HAVE_WCSPBRK */
 
 /* Define to 1 if you have the `wcsrchr' function. */
-#define _GLIBCXX_HAVE_WCSRCHR 1
+/* #undef _GLIBCXX_HAVE_WCSRCHR */
 
 /* Define to 1 if you have the `wcsrtombs' function. */
-#define _GLIBCXX_HAVE_WCSRTOMBS 1
+/* #undef _GLIBCXX_HAVE_WCSRTOMBS */
 
 /* Define to 1 if you have the `wcsspn' function. */
-#define _GLIBCXX_HAVE_WCSSPN 1
+/* #undef _GLIBCXX_HAVE_WCSSPN */
 
 /* Define to 1 if you have the `wcsstr' function. */
-#define _GLIBCXX_HAVE_WCSSTR 1
+/* #undef _GLIBCXX_HAVE_WCSSTR */
 
 /* Define to 1 if you have the `wcstod' function. */
-#define _GLIBCXX_HAVE_WCSTOD 1
+/* #undef _GLIBCXX_HAVE_WCSTOD */
 
 /* Define to 1 if you have the `wcstof' function. */
 /* #undef _GLIBCXX_HAVE_WCSTOF */
 
 /* Define to 1 if you have the `wcstok' function. */
-#define _GLIBCXX_HAVE_WCSTOK 1
+/* #undef _GLIBCXX_HAVE_WCSTOK */
 
 /* Define to 1 if you have the `wcstol' function. */
-#define _GLIBCXX_HAVE_WCSTOL 1
+/* #undef _GLIBCXX_HAVE_WCSTOL */
 
 /* Define to 1 if you have the `wcstoul' function. */
-#define _GLIBCXX_HAVE_WCSTOUL 1
+/* #undef _GLIBCXX_HAVE_WCSTOUL */
 
 /* Define to 1 if you have the `wcsxfrm' function. */
-#define _GLIBCXX_HAVE_WCSXFRM 1
+/* #undef _GLIBCXX_HAVE_WCSXFRM */
 
 /* Define to 1 if you have the `wctob' function. */
-#define _GLIBCXX_HAVE_WCTOB 1
+/* #undef _GLIBCXX_HAVE_WCTOB */
 
 /* Define to 1 if you have the <wctype.h> header file. */
-#define _GLIBCXX_HAVE_WCTYPE_H 1
+/* #undef _GLIBCXX_HAVE_WCTYPE_H */
 
 /* Define to 1 if you have the `wmemchr' function. */
-#define _GLIBCXX_HAVE_WMEMCHR 1
+/* #undef _GLIBCXX_HAVE_WMEMCHR */
 
 /* Define to 1 if you have the `wmemcmp' function. */
-#define _GLIBCXX_HAVE_WMEMCMP 1
+/* #undef _GLIBCXX_HAVE_WMEMCMP */
 
 /* Define to 1 if you have the `wmemcpy' function. */
-#define _GLIBCXX_HAVE_WMEMCPY 1
+/* #undef _GLIBCXX_HAVE_WMEMCPY */
 
 /* Define to 1 if you have the `wmemmove' function. */
-#define _GLIBCXX_HAVE_WMEMMOVE 1
+/* #undef _GLIBCXX_HAVE_WMEMMOVE */
 
 /* Define to 1 if you have the `wmemset' function. */
-#define _GLIBCXX_HAVE_WMEMSET 1
+/* #undef _GLIBCXX_HAVE_WMEMSET */
 
 /* Define to 1 if you have the `wprintf' function. */
 /* #undef _GLIBCXX_HAVE_WPRINTF */
@@ -984,7 +1000,7 @@ namespace std
 #define _GLIBCXX_HOSTED 1
 
 /* Define if the compiler is configured for setjmp/longjmp exceptions. */
-#define _GLIBCXX_SJLJ_EXCEPTIONS 1
+/* #undef _GLIBCXX_SJLJ_EXCEPTIONS */
 //
 // Systems that have certain non-standard functions prefixed with an
 // underscore, we'll handle those here. Must come after config.h.in.
